@@ -117,7 +117,7 @@ def normalize_namespace(namespace, ptype, encode=True):  # NOQA
         namespace = namespace.decode('utf-8')
 
     namespace = namespace.strip().strip('/')
-    if ptype in ('bitbucket', 'github', 'pypi'):
+    if ptype in ('bitbucket', 'github', 'pypi', 'gitlab'):
         namespace = namespace.lower()
     segments = [seg for seg in namespace.split('/') if seg.strip()]
     segments = map(get_quoter(encode), segments)
@@ -133,7 +133,7 @@ def normalize_name(name, ptype, encode=True):  # NOQA
     quoter = get_quoter(encode)
     name = quoter(name)
     name = name.strip().strip('/')
-    if ptype in ('bitbucket', 'github', 'pypi',):
+    if ptype in ('bitbucket', 'github', 'pypi', 'gitlab'):
         name = name.lower()
     if ptype in ('pypi',):
         name = name.replace('_', '-')
@@ -285,16 +285,20 @@ class PackageURL(namedtuple('PackageURL', _components)):
     def __hash__(self):
         return hash(self.to_string())
 
-    def to_dict(self, encode=False):
+    def to_dict(self, encode=False, empty=None):
         """
-        Return an ordered dict of purl components as {key: value}. If `encode`
-        is True, then "qualifiers" are encoded as a normalized string.
-        Otherwise, qualifiers is a mapping.
+        Return an ordered dict of purl components as {key: value}.
+        If `encode` is True, then "qualifiers" are encoded as a normalized
+        string. Otherwise, qualifiers is a mapping.
+        You can provide a value for `empty` to be used in place of default None.
         """
         data = self._asdict()
         if encode:
-            data['qualifiers'] = normalize_qualifiers(self.qualifiers,
-                                                      encode=encode)
+            data['qualifiers'] = normalize_qualifiers(self.qualifiers, encode=encode)
+
+        for field, value in data.items():
+            data[field] = value or empty
+
         return data
 
     def to_string(self):
