@@ -287,6 +287,36 @@ class NormalizePurlTest(unittest.TestCase):
         ])
         assert expected == purl.to_dict(encode=True)
 
+    def test_to_dict_custom_empty_value(self):
+        purl = PackageURL(
+            type='maven',
+            namespace='',
+            name='commons-logging',
+            version='12.3',
+            qualifiers=None,
+        )
+
+        expected = OrderedDict([
+            ('type', 'maven'),
+            ('namespace', None),
+            ('name', 'commons-logging'),
+            ('version', '12.3'),
+            ('qualifiers', None),
+            ('subpath', None)
+        ])
+        assert expected == purl.to_dict()
+        assert expected == purl.to_dict(empty=None)
+
+        expected = OrderedDict([
+            ('type', 'maven'),
+            ('namespace', ''),
+            ('name', 'commons-logging'),
+            ('version', '12.3'),
+            ('qualifiers', ''),
+            ('subpath', '')
+        ])
+        assert expected == purl.to_dict(empty='')
+
 
 def test_purl_is_hashable():
     s = {PackageURL(name='hashable', type='pypi')}
